summaryrefslogtreecommitdiff
path: root/sw/inc/anchoredobject.hxx
diff options
context:
space:
mode:
authorRĂ¼diger Timm <rt@openoffice.org>2004-08-23 07:00:41 +0000
committerRĂ¼diger Timm <rt@openoffice.org>2004-08-23 07:00:41 +0000
commitdf6086a779af03106703c01f5f5851eb92c7f14f (patch)
tree4e46f2ad88dfa41b9e9bf6b126bac42e25277791 /sw/inc/anchoredobject.hxx
parent22f1f4e13f17117987e9fbf1f8311db23962d31a (diff)
INTEGRATION: CWS swdrawobjapi (1.2.60); FILE MERGED
2004/08/12 06:56:40 od 1.2.60.2: RESYNC: (1.2-1.4); FILE MERGED resolve merge conflicts. 2004/07/29 13:20:05 od 1.2.60.1: #i31698# - adjustments for changed drawing object API in Writer
Diffstat (limited to 'sw/inc/anchoredobject.hxx')
-rw-r--r--sw/inc/anchoredobject.hxx20
1 files changed, 16 insertions, 4 deletions
diff --git a/sw/inc/anchoredobject.hxx b/sw/inc/anchoredobject.hxx
index ff798ee2b89f..f62e6facdae5 100644
--- a/sw/inc/anchoredobject.hxx
+++ b/sw/inc/anchoredobject.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: anchoredobject.hxx,v $
*
- * $Revision: 1.4 $
+ * $Revision: 1.5 $
*
- * last change: $Author: od $ $Date: 2004-08-03 05:55:53 $
+ * last change: $Author: rt $ $Date: 2004-08-23 08:00:41 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -105,7 +105,7 @@ class SwAnchoredObject
// note: no page frame for as-character anchored objects
SwPageFrm* mpPageFrm;
// <--
- // last relative position
+ // current relative position (relative to anchor position of anchor frame)
Point maRelPos;
// for to-character anchored objects:
@@ -344,7 +344,8 @@ class SwAnchoredObject
const SwRect& _rRect,
PrepareHint _eHint ) = 0;
// accessors to the current relative position
const Point GetCurrRelPos() const;
void SetCurrRelPos( Point _aRelPos );
@@ -357,6 +358,17 @@ class SwAnchoredObject
virtual void SetObjTop( const SwTwips _nTop) = 0;
virtual void SetObjLeft( const SwTwips _nLeft) = 0;
+ /** method update layout direction the layout direction, the anchored
+ object is assigned to
+
+ OD 2004-07-27 #i31698#
+ method has typically to be called, if the anchored object gets its
+ anchor frame assigned and if the anchor frame changes its layout direction
+
+ @author OD
+ */
+ void UpdateLayoutDir();
+
/** method to determine object area inclusive its spacing
OD 2004-06-30 #i28701#
@@ -344,7 +344,8 @@ class SwAnchoredObject
const SwRect& _rRect,
PrepareHint _eHint ) = 0;
- // accessors to the current relative position
+ // accessors to the current relative position (relative to anchor
+ // position of anchor frame)
const Point GetCurrRelPos() const;
void SetCurrRelPos( Point _aRelPos );